Welcome to Multilanguage ChatGPT word-def plugin's documentation!
==========================================

Multilanguage plugin for word-def

Start here
================
.. toctree::
   :maxdepth: 1

   getting-started

Reference guides
================

.. toctree::
   :maxdepth: 1

   plugin-module
